@@ -57,9 +57,7 @@ class MultiplesExperimentos:
                                                     procesar_tiempo_archivo_irregular=
                                                     self.procesar_tiempo_archivo_irregular,
                                                     puntos_importantes=self.puntos_importantes)
-                    nuevo_experimento.calcula_velocidades()
-                    nuevo_experimento.calcula_regiones_cuadriculadas()
-                    nuevo_experimento.calcula_matrices_solo_regiones_preferidas()
+
                     self.lista_experimentos.append(nuevo_experimento)
         else:
             for archivo in self.lista_archivos:
